@@ -20,6 +20,7 @@ from typing import Any, ClassVar, Dict, Generic, List, Optional, Tuple, Type, Ty
 
 from pydantic import BaseModel  # pylint: disable=no-name-in-module
 
+from autotransform.config import get_config
 from autotransform.event.debug import DebugEvent
 from autotransform.event.handler import EventHandler
 from autotransform.event.warning import WarningEvent
@@ -49,7 +50,7 @@ class ComponentModel(BaseModel):
             Dict[str, Any]: The encodable bundle.
         """
 
-        bundle = dict(self._iter(to_dict=False, exclude_defaults=True))
+        bundle = dict(self._iter(to_dict=False, exclude_defaults=True, exclude_unset=True))
         for key, value in bundle.items():
             if isinstance(value, ComponentModel):
                 bundle[key] = value.bundle()
@@ -98,11 +99,12 @@ class ComponentModel(BaseModel):
             else:
                 lines.append(f"\t{name}={field_val!r},".replace("\n", "\n\t"))
         lines.append(")")
-        return "\n".join(lines)
+        return "\n".join(lines).replace("\t", "    ")
 
 
 class NamedComponent(ComponentModel):
-    """A base class for AutoTransform components, such as Batchers.
+    """A base class for AutoTransform components that are produced from a factory using
+    a name to differentiate component classes.
 
     Attributes:
         name (ClassVar[Enum]): The name of the Component.
@@ -379,9 +381,8 @@ class ComponentFactory(Generic[T], ABC):
             str: The path where the custom component JSON is located.
         """
         # Importing here to avoid a cyclic import
-        import autotransform.config  # pylint: disable=import-outside-toplevel
 
-        return f"{autotransform.config.CONFIG.component_directory}/{component_file_name}"
+        return f"{get_config().component_directory}/{component_file_name}"
 
     def _get_component_class(
         self,
