@@ -13,13 +13,15 @@ from __future__ import annotations
 
 import time
 from datetime import datetime, timedelta
-from typing import Any, Dict, List, Optional
+from functools import cached_property
+from typing import Any, Dict, List, Optional, Tuple
 from urllib.error import HTTPError
 
 import pytz
 from fastcore.basics import AttrDict  # type: ignore
 from ghapi.all import GhApi, gh2date  # type: ignore
 
+from autotransform.config import get_config
 from autotransform.event.debug import DebugEvent
 from autotransform.event.handler import EventHandler
 
@@ -51,11 +53,9 @@ class GithubUtils:
                 format {owner}/{repo}.
         """
 
-        import autotransform.config  # pylint: disable=import-outside-toplevel
-
         assert fully_qualified_repo not in GithubUtils.__instances
-        token = autotransform.config.CONFIG.github_token
-        url = autotransform.config.CONFIG.github_base_url
+        token = get_config().github_token
+        url = get_config().github_base_url
         repo_parts = fully_qualified_repo.split("/")
         self._api = GhApi(token=token, gh_host=url, owner=repo_parts[0], repo=repo_parts[1])
 
@@ -249,6 +249,48 @@ class PullRequest:
                 return review.state
         return None
 
+    def get_labels(self) -> List[str]:
+        """Gets the labels for a Pull Request.
+
+        Returns:
+            List[str]: The labels for a Pull Request.
+        """
+
+        labels = self._api.issues.list_labels_on_issue(issue_number=self.number)
+        return [label["name"] for label in labels]
+
+    def get_reviewers(self) -> List[str]:
+        """Gets the requested reviewers for a Pull Request.
+
+        Returns:
+            List[str]: The requested reviewers for a Pull Request.
+        """
+
+        return self._reviewers[0]
+
+    def get_team_reviewers(self) -> List[str]:
+        """Gets the requested team reviewers for a Pull Request.
+
+        Returns:
+            List[str]: The requested team reviewers for a Pull Request.
+        """
+
+        return self._reviewers[1]
+
+    @cached_property
+    def _reviewers(self) -> Tuple[List[str], List[str]]:
+        """A cached value of the reviewers of the change.
+
+        Returns:
+            Tuple[List[str], List[str]]: A tuple containing user reviewers and team reviewers.
+        """
+
+        reviewers = self._api.pulls.list_requested_reviewers(pull_number=self.number)
+        return (
+            [reviewer["login"] for reviewer in reviewers["users"]],
+            [reviewer["name"] for reviewer in reviewers["teams"]],
+        )
+
     def get_created_at(self) -> int:
         """Gets the created at timestamp.
 
@@ -283,9 +325,20 @@ class PullRequest:
         """
 
         self._api.pulls.request_reviewers(
-            pull_number=self.number, reviewers=reviewers, team_reviewers=team_reviewers
+            pull_number=self.number,
+            reviewers=list(set(reviewers)),
+            team_reviewers=list(set(team_reviewers)),
         )
 
+    def create_comment(self, body: str) -> None:
+        """Adds a comment to the pull request.
+
+        Args:
+            body (str): The body of the comment.
+        """
+
+        self._api.issues.create_comment(issue_number=self.number, body=body)
+
     def merge(self) -> bool:
         """Merges the pull request.
 
@@ -302,6 +355,15 @@ class PullRequest:
             )
             return False
 
+    def remove_label(self, label: str) -> None:
+        """Removes a label from the pull request.
+
+        Args:
+            label (str): The label to remove from the pull request.
+        """
+
+        self._api.issues.remove_label(issue_number=self.number, name=label)
+
     def close(self) -> bool:
         """Closes the pull request.
 
