@@ -25,7 +25,7 @@ from autotransform.repo.git import GitRepo
 from autotransform.repo.github import GithubRepo
 from autotransform.runner.base import FACTORY as runner_factory
 from autotransform.runner.base import Runner
-from autotransform.step.action import ActionType
+from autotransform.step.action.source import AbandonAction, MergeAction, UpdateAction
 from autotransform.step.base import FACTORY as step_factory
 from autotransform.step.base import Step
 from autotransform.step.condition.comparison import ComparisonType
@@ -59,19 +59,18 @@ class Manager(ComponentModel):
 
         changes = self.repo.get_outstanding_changes()
         for change in changes:
-            EventHandler.get().handle(DebugEvent({"message": f"Checking steps for {str(change)}"}))
+            EventHandler.get().handle(DebugEvent({"message": f"Checking steps for {change!r}"}))
             for step in self.steps:
-                EventHandler.get().handle(DebugEvent({"message": f"Checking step {str(step)}"}))
-                action = step.get_action(change)
-                if action["type"] != ActionType.NONE:
+                EventHandler.get().handle(DebugEvent({"message": f"Checking step {step!r}"}))
+                actions = step.get_actions(change)
+                for action in actions:
                     EventHandler.get().handle(
                         ManageActionEvent({"action": action, "change": change, "step": step})
                     )
-                    change.take_action(action["type"], self.runner)
-                if action["stop_steps"]:
-                    EventHandler.get().handle(
-                        DebugEvent({"message": f"Steps ended for change {str(change)}"})
-                    )
+                    change.take_action(action, self.runner)
+
+                if actions and not step.continue_management(change):
+                    EventHandler.get().handle(DebugEvent({"message": "Steps ended"}))
                     break
 
     def write(self, file_path: str) -> None:
@@ -154,16 +153,16 @@ class Manager(ComponentModel):
         """
 
         if repo_name == RepoName.GITHUB:
-            base_branch_name = get_str(
+            base_branch = get_str(
                 "Enter the name of the base branch for the repo(i.e. main, master): "
             )
             github_name = get_str("Enter the fully qualified name of the github repo(owner/repo): ")
-            repo: Repo = GithubRepo(base_branch_name=base_branch_name, full_github_name=github_name)
+            repo: Repo = GithubRepo(base_branch=base_branch, full_github_name=github_name)
         elif repo_name == RepoName.GIT:
-            base_branch_name = get_str(
+            base_branch = get_str(
                 "Enter the name of the base branch for the repo(i.e. main, master): "
             )
-            repo = GitRepo(base_branch_name=base_branch_name)
+            repo = GitRepo(base_branch=base_branch)
         else:
             input_repo = repo_factory.from_console("repo", allow_none=False)
             assert input_repo is not None
@@ -182,9 +181,9 @@ class Manager(ComponentModel):
             steps.append(
                 ConditionalStep(
                     condition=ChangeStateCondition(
-                        comparison=ComparisonType.EQUAL, state=ChangeState.APPROVED
+                        comparison=ComparisonType.EQUAL, value=ChangeState.APPROVED
                     ),
-                    action=ActionType.MERGE,
+                    actions=[MergeAction()],
                 )
             )
 
@@ -193,9 +192,9 @@ class Manager(ComponentModel):
             steps.append(
                 ConditionalStep(
                     condition=ChangeStateCondition(
-                        comparison=ComparisonType.EQUAL, state=ChangeState.CHANGES_REQUESTED
+                        comparison=ComparisonType.EQUAL, value=ChangeState.CHANGES_REQUESTED
                     ),
-                    action=ActionType.ABANDON,
+                    actions=[AbandonAction()],
                 )
             )
 
@@ -209,9 +208,9 @@ class Manager(ComponentModel):
                 ConditionalStep(
                     condition=UpdatedAgoCondition(
                         comparison=ComparisonType.GREATER_THAN_OR_EQUAL,
-                        time=days_stale * 24 * 60 * 60,
+                        value=days_stale * 24 * 60 * 60,
                     ),
-                    action=ActionType.ABANDON,
+                    actions=[UpdateAction()],
                 )
             )
 
